<?php
/**
 * @version $Id: joobbengine.php 589 2009-08-23 20:50:25Z robste $
 * @package Joo!BB
 * @copyright Copyright (C) 2007-2009 Sonixsoft. All rights reserved.
 * @license GNU/GPL. Please see license.php in Joo!BB directory 
 * for copyright notices and details.
 * Joo!BB is free software. This version may have been NOT modified.
 */

// no direct access
defined('_JEXEC') or die('Restricted access');

/**
 * Joo!BB Engine
 *
 * @package Joo!BB
 */
class JoobbEngine
{
	/**
	 * authentification data
	 *
	 * @var array
	 */
	var $_joobbEmotionSet;

	function JoobbEngine() {
		$joobbConfig =& JoobbConfig::getInstance();
	
		// emotion set
		$this->_joobbEmotionSet =& JoobbEmotionSet::getInstance($joobbConfig->getEmotionSetFile());	
	}
	
	/**
	 * get instance
	 *
	 * @access 	public
	 * @return object
	 */
	function &getInstance() {
		static $joobbEngine;

		if (!is_object($joobbEngine)) {
			$joobbEngine = new JoobbEngine();
		}

		return $joobbEngine;
	}
	
	function convertToHtml(&$post) {
		$joobbConfig =& JoobbConfig::getInstance();
		
		// look up emotions in post
		if ($joobbConfig->getBoardSettings('enable_emotions') && $post->enable_emotions) {
			foreach ($this->_joobbEmotionSet->codesList as $emotionCode) {
				$post->text = str_replace($emotionCode[0], '<img src="'. $emotionCode[1]->fileName .'" title="'. JText::_($emotionCode[1]->emotion) 
															.'" alt="'. JText::_($emotionCode[1]->emotion) .'" class="jbEmotion" />', $post->text);
			}
		}
			
		// replace bb codes
		if ($joobbConfig->getBoardSettings('enable_bbcode') && $post->enable_bbcode) {
			$post->text = $this->convertBBToHtml($post->text);
		}

		// replace text
		$post->text = str_replace("\n", "<br />", $post->text);		

	}
	
	function convertBBToHtml($string) {
		$oldString = '';
		while ($oldString != $string) {
			$oldString = $string;
			//$string = preg_replace_callback('{\[(\w+)((=)(.+)|())\]((.|\n)*)\[/\1\]}U', array($this, 'convertBBToHtmlCallback'), $string);
			$string = preg_replace_callback('{\[(\w+)((?:\s|=)[^]]*)?]((?:[^[]|\[(?!/?\1((?:\s|=)[^]]*)?])|(?R))+)\[/\1]}U', array($this, 'convertBBToHtmlCallback'), $string);			
		}
		
		// remove the no parse identifier
		$string = str_replace("[noparse]", "", $string); 
		$string = str_replace("[/noparse]", "", $string);

		return $string;
	}

	function convertBBToHtmlCallback($matches) {
		$tag = trim($matches[1]);
		$argument = str_replace("=", "", $matches[2]);
		$innerString = $matches[3];
//print_r($matches);
		switch ($tag) {
			case 'b': // bold
				$replacement = '<strong>'.$innerString.'</strong>';
				break;
			case 'i': // italic
			case 'u': // underline
			case 's': // strikeout
				$replacement = '<'.$tag.'>'.$innerString.'</'.$tag.'>';
				break;
				
			case 'left':
				$replacement = '<div align="left">'.$innerString.'</div>';
				break;
			case 'center':
				$replacement = '<div align="center">'.$innerString.'</div>';
				break;
			case 'right':
				$replacement = '<div align="right">'.$innerString.'</div>';
				break;
			case 'justify':
				$replacement = '<div align="justify">'.$innerString.'</div>';
				break;
				
			case 'code':
				$joobbConfig =& JoobbConfig::getInstance();
				$joobbGeSHi = &JoobbGeSHi::getInstance();
				
				$languages = spliti(' ', $argument);
				
				$joobbGeSHi->enable_line_numbers($joobbConfig->getParseSettings('enable_line_numbers'));
				$joobbGeSHi->set_link_target($joobbConfig->getParseSettings('link_target'));

				$replacement = $innerString;
				foreach ($languages as $language) {
					$joobbGeSHi->set_source($replacement);
					$joobbGeSHi->set_language($language);
					$joobbGeSHi->enable_classes(false);
					$replacement = $joobbGeSHi->parse_code();
				}

				$replacement = '[noparse]<span class="codetext">'.JText::_('BB_CODE').'</span>'. $replacement .'[/noparse]';
				break;
	
			case 'color':
				$color = preg_match("[^[0-9a-fA-F]{3,6}$]", $argument) ? '#'. $argument : $argument;
				$replacement = '<font color="'.$color.'">'. $innerString .'</font>'; 
				break;
	
			case 'url':
				$innerString = $this->removeAllInnerTags($innerString);
				$url = $argument ? $argument : $innerString;

				// make sure the url begins with http://
				if (!preg_match('/^http:\/\//i', $url) && !preg_match('/^ftp:\/\//i', $url) && 
					!preg_match('/^gopher:\/\//i', $url) && !preg_match('/^telnet:\/\//i', $url)) {
					$url = 'http://'. $url;
				}
				
				$replacement = '<a href="'. $url .'" target="_blank">'. $innerString .'</a>';
				break;
	
			case 'email':
				$address = $argument ? $argument : $innerString;
				$replacement = '<a href="mailto:'. $address .'">'. $innerString .'</a>';
				break;
	
			case 'img':
				$innerString = $this->removeAllInnerTags($innerString);
				$size = spliti('x', $argument);
				$width = ''; $height = '';

				if (isset($size[0]) && $size[0] != '' && $size[0] != 0) {
					$width = '" width="'.$size[0];
				}
				if (isset($size[1]) && $size[1] != '' && $size[1] != 0) {
					$height = '" height="'.$size[1];
				}
				
				$replacement = '<img src="' . $innerString.$width.$height.'" border="0"/>';
				break;
	
			case 'thread':
				$innerString = $this->removeAllInnerTags($innerString);
				$topicId = (int) $innerString;
				$Itemid = JoocmHelper::getItemId('com_joobb');
				$replacement = '';
				
				if ($topicId) {
					$db	= & JFactory::getDBO();
					
					$query = "SELECT p.id, p.subject, p.id_topic"
							. "\n FROM #__joobb_topics AS t"
							. "\n INNER JOIN #__joobb_posts AS p ON t.id_first_post = p.id"
							. "\n WHERE t.id = ". $topicId
							;
					$db->setQuery($query);
					$row = $db->loadObject();
					
					if ($row) {
						$url = JRoute::_('index.php?option=com_joobb&view=topic&topic='. $row->id_topic .'&Itemid='. $Itemid);
						$replacement = '<a href="'. $url .'">'. $row->subject .'</a>';
					}
				}
				break;
	
			case 'post':
				$innerString = $this->removeAllInnerTags($innerString);
				$postId = (int) $innerString;
				$Itemid = JoocmHelper::getItemId('com_joobb');
				$replacement = '';
				
				if ($postId) {
					$db	= & JFactory::getDBO();
					
					$query = "SELECT p.id, p.subject, p.id_topic"
							. "\n FROM #__joobb_posts AS p"
							. "\n INNER JOIN #__joobb_topics AS t ON t.id = p.id_topic"
							. "\n WHERE p.id = ". $postId
							;
					$db->setQuery($query);
					$row = $db->loadObject();
					
					if ($row) {
						$url = JRoute::_('index.php?option=com_joobb&view=topic&topic='. $row->id_topic .'&Itemid='. $Itemid .'#p'. $row->id);
						$replacement = '<a href="'. $url .'">'. $row->subject .'</a>';
					}
				}
				break;
		
			case 'youtube':
				$joobbConfig =& JoobbConfig::getInstance();

				$width = $joobbConfig->getParseSettings('youtube_width');
				$height = $joobbConfig->getParseSettings('youtube_height');
				$fullScreen = $joobbConfig->getParseSettings('youtube_allow_fullscreen');
				
				$innerString = $this->removeAllInnerTags($innerString);

				$replacement = '<object width="'. $width .'" height="'. $height .'">'
							 . '<param name="movie" value="http://www.youtube.com/v/'. $innerString .'"></param>'
							 . '<param name="allowFullScreen" value="'. $fullScreen .'"></param>'
							 . '<param name="allowScriptAccess" value="always"></param>'
							 . '<embed src="http://www.youtube.com/v/'. $innerString .'" type="application/x-shockwave-flash" allowFullScreen="'. $fullScreen .'" allowScriptAccess="always" width="'. $width .'" height="'. $height .'"></embed>'
							 . '</object>';
				break;
	
			case 'gvideo':
				$replacement = '<embed style="width:425px; height:344px;" id="VideoPlayback" type="application/x-shockwave-flash" src="http://video.google.com/googleplayer.swf?docId=' . $innerString . '"></embed>';
				break;
	
			case 'list':
				$tag = ($argument == 'l') ? 'ol' : 'ul';
				$innerString = preg_replace('/\[\*\](.*?)\\n/si', '<li>$1</li>', $innerString);
				$replacement = '<'.$tag.' class="list">' . $innerString . '</'.$tag.'>';
				break;
			
			case 'size':
				if (preg_match('/px/i', $argument)) {
					$replacement =  '<span style="font-size:'. $argument .';">'. $innerString .'</span>';
				} else {
					$replacement =  '<font size="'. $argument .'">'. $innerString .'</font>';
				}
				break;
			
			case 'font':
			    $replacement = '<div><span style="font-family: ' . $argument . '">' . $innerString . '</span></div>';
				break;

			case 'quote':
				$quotedUser = (isset($argument) && $argument != '') ? $argument : JText::_('BB_UNKNOWN');
				$replacement = '<span class="quotebyuser">'.JText::_('BB_QUOTEBY').' '.$quotedUser.':</span><span class="quote">' . $innerString . '</span>';
				break;

			case 'table':
			    $param = $argument ? $argument : 'border="1" cellspacing="0" cellpadding="0" width="100%"';
				$replacement = '<table ' . $param . '>' . $innerString . '</table>';
				break;
			case 'tr':
			    $param = $argument ? $argument : 'bgcolor="#ffffff"';
				$replacement = '<tr ' . $param . '>' . $innerString . '</tr>';
				break;
			case 'th':
			    $param = $argument ? $argument : 'bgcolor="#f1f1f1" width="*"';
				$replacement = '<th ' . $param . '><strong>' . $innerString . '</strong></th>';
				break;
			case 'td':
			    $param = $argument ? $argument : 'width="*"';
				$replacement = '<td ' . $param . '>' . $innerString . '</td>';
				break;
				
			case 'noparse':	
			default:    // unknown tag => reconstruct and return original expression
				$replacement = '[' . $tag . ']' . $innerString . '[/' . $tag .']';
				break;
		}
	
		return $replacement;
	}
	
	function removeAllInnerTags($innerString) {
		return preg_replace('{\[(\w+)((=)(.+)|())\]|\[/\w+]}', '', $innerString);
	}	
}

?>