<?php
/**
 * @version $Id: joobbiconset.php 449 2009-02-03 10:10:13Z robste $
 * @package Joo!BB
 * @copyright Copyright (C) 2007-2008 Sonixsoft. All rights reserved.
 * @license GNU/GPL. Please see license.php in Joo!BB directory 
 * for copyright notices and details.
 * Joo!BB is free software. This version may have been NOT modified.
 */

// no direct access
defined('_JEXEC') or die('Restricted access');

/**
 * Joo!BB Icon Set
 *
 * @package Joo!BB
 */
class JoobbIconSet
{
	/**
	 * The manifest XML object
	 * @var object
	 */
	var $_xml = null;
	
	var $name;
	
	var $xmlFile;
	
	var $icons;
	
	var $iconByFunction;
	
	function JoobbIconSet($xmlFile) {
		
		// initialize variables
		$messageQueue	=& JoobbMessageQueue::getInstance();
		
		$this->name = basename($xmlFile, ".xml");
		$this->xmlFile = $xmlFile;
		$this->icons = array();
		
		if (file_exists(JOOBB_ICONS.DS.$this->name.DS.$xmlFile)) {
			$this->_xml =& JFactory::getXMLParser('Simple');
			$this->_xml->loadFile(JOOBB_ICONS.DS.$this->name.DS.$xmlFile);
	
			$root = & $this->_xml->document;
			$iconSet = $root->getElementByPath('iconset');

			if ($iconSet) {
				
				// load language file
				if ($iconSet->attributes('translateable')) {
					$this->loadLanguage($xmlFile);
				}

				$elements = $iconSet->children();
	
				foreach ($elements as $element) {
					$icon = new StdClass();
					$icon->fileName = JOOBB_ICONS_LIVE.DL.$this->name.DL.$element->attributes('filename');
					$icon->group = $element->attributes('group');
					$icon->function = $element->attributes('function');
					$icon->title = JText::_($element->attributes('title'));
					$this->icons[] = $icon;
					$this->iconByFunction[$icon->function] = $icon;
				}
			} else {
				$messageQueue->addMessage(JText::sprintf('BB_MSGXMLPARSINGERROR', JText::_('BB_ICONSET'), JOOBB_ICONS.DS.$this->name.DS.$xmlFile));
			}
		} else {
			$messageQueue->addMessage(JText::sprintf('BB_MSGRESSOURCENOTFOUND', JText::_('BB_ICONSET'), JOOBB_ICONS.DS.$this->name.DS.$xmlFile));
		}		
	}
	
	/**
	 * get instance
	 *
	 * @access 	public
	 * @return object
	 */
	function &getInstance() {
	
		static $joobbIconSet;

		if (!is_object($joobbIconSet)) {
			$joobbConfig	=& JoobbConfig::getInstance();
			$joobbIconSet = new JoobbIconSet($joobbConfig->getIconSetFile());
		}

		return $joobbIconSet;
	}
	
	/**
	 * get icons by group
	 *
	 * @access 	public
	 * @return array
	 */
	function getIconsByGroup($iconGroup) {

		$icons = array();
		foreach ($this->icons as $icon) {
			if ($icon->group == $iconGroup) {
				$icons[] = $icon;
			}
		}
		return $icons;
	}
	
	/**
	 * load language
	 *
	 * @access 	public
	 */		
	function loadLanguage($xmlFile) {
	
		// initialize variables
		$messageQueue	=& JoobbMessageQueue::getInstance();
		
		// load language file for icon set
		$langFile = JOOBB_ICONS.DS.$this->name.DS.JoobbHelper::getLocale().DS.$this->name.'.ini';
		
		if (!is_file($langFile)) {
			$langFile = JOOBB_ICONS.DS.$this->name.DS.'en-GB'.DS.$this->name.'.ini';	
		}	
			
		if (is_file($langFile)) {		
			$lang =& JFactory::getLanguage();
			$lang->_load($langFile); // sorry for calling private function, but there is no other solution at the moment!
		} else {
			$messageQueue->addMessage(JText::sprintf('BB_MSGNOLANGUAGEFILE', JText::_('BB_ICONSET')));
		}
	}

}
?>